@@ -1,5 +1,5 @@
 ## File Name: ANSI_create_table.R
-## File Version: 0.574
+## File Version: 0.580
 
 
 #*** create table with results
@@ -32,14 +32,14 @@ ANSI_create_table <- function (dat, criterion,
     #--- horizontal variables
     NH <- length(horiz_vars)
     if ( is.null(horiz_vals) ){
-        horiz_vals <- as.list(1:NH)
+        horiz_vals <- as.list(1L:NH)
         names(horiz_vals) <- horiz_vars
-        for (nn in 1:NH){
+        for (nn in 1L:NH){
             horiz_vals[[nn]] <- sort( unique( x[, horiz_vars[nn]] ) )
         }
     }
     if ( ! is.null(horiz_vals) ){
-        horiz_vals1 <- as.list(1:NH)
+        horiz_vals1 <- as.list(1L:NH)
         names(horiz_vals1) <- horiz_vars
         if ( ! is.null( names(horiz_vals) ) ){
             for (nn in horiz_vars)
@@ -49,9 +49,9 @@ ANSI_create_table <- function (dat, criterion,
             }
             horiz_vals <- horiz_vals1
     }
-    h2 <- as.list( 1:NH)
+    h2 <- as.list( 1L:NH)
     names(h2) <- horiz_vars[ seq(NH,1,-1) ]
-    for (nn in 1:NH){
+    for (nn in 1L:NH){
         h2[[NH-nn+1]] <- horiz_vals[[nn]]
     }
     horiz_table <- expand.grid( h2 )[, seq(NH,1,-1),drop=FALSE]
@@ -61,14 +61,14 @@ ANSI_create_table <- function (dat, criterion,
     #--- vertical variables
     NH <- length(vert_vars)
     if ( is.null(vert_vals) ){
-        vert_vals <- as.list( 1:NH)
+        vert_vals <- as.list( 1L:NH)
         names(vert_vals) <- vert_vars
-        for (nn in 1:NH){
+        for (nn in 1L:NH){
             vert_vals[[nn]] <- sort( unique( x[, vert_vars[nn]] ) )
         }
     }
     if ( ! is.null(vert_vals) ){
-        vert_vals1 <- as.list(1:NH)
+        vert_vals1 <- as.list(1L:NH)
         names(vert_vals1) <- vert_vars
         if ( ! is.null( names(vert_vals) ) ){
             for (nn in vert_vars)
@@ -78,9 +78,9 @@ ANSI_create_table <- function (dat, criterion,
         }
         vert_vals <- vert_vals1
     }
-    h2 <- as.list( 1:NH)
+    h2 <- as.list( 1L:NH)
     names(h2) <- vert_vars[ seq(NH,1,-1) ]
-    for (nn in 1:NH){
+    for (nn in 1L:NH){
         h2[[NH-nn+1]] <- vert_vals[[nn]]
     }
     vert_table <- expand.grid(h2)[, seq(NH,1,-1),drop=FALSE]
@@ -90,14 +90,14 @@ ANSI_create_table <- function (dat, criterion,
     #--- create complete table
     dfr <- matrix( NA, nrow=horiz_NR, ncol=vert_NR)
     NN <- nrow(x)
-    for (hr in 1:horiz_NR){
-        for (vr in 1:vert_NR){
-            ind <- 1:NN
-            for (nn in 1:horiz_NC){
+    for (hr in 1L:horiz_NR){
+        for (vr in 1L:vert_NR){
+            ind <- 1L:NN
+            for (nn in 1L:horiz_NC){
                 ind0 <- which(  paste(x[, horiz_vars[nn] ])==paste(horiz_table[hr,nn]) )
                 ind <- intersect( ind, ind0 )
             }
-            for (nn in 1:vert_NC){
+            for (nn in 1L:vert_NC){
                 ind0 <- which( paste(x[, vert_vars[nn] ])==paste(vert_table[vr,nn]) )
                 ind <- intersect( ind, ind0 )
             }
@@ -113,22 +113,21 @@ ANSI_create_table <- function (dat, criterion,
         }
     }
 
-    #****
-    # labels horizontal variables
+    #*** labels horizontal variables
     nn <- 1
     cn <- paste0( horiz_vars[nn], "=", horiz_table[,nn] )
     if (horiz_NC>1){
-        for (nn in 2:horiz_NC){
+        for (nn in 2L:horiz_NC){
             cn <- paste0( cn, " # ", horiz_vars[nn], "=", horiz_table[,nn] )
         }
     }
     rownames(dfr) <- cn
-    #****
-    # labels vertical variables
+
+    #*** labels vertical variables
     nn <- 1
     cn <- paste0( vert_vars[nn], "=", vert_table[,nn] )
     if (vert_NC>1){
-        for (nn in 2:vert_NC){
+        for (nn in 2L:vert_NC){
             cn <- paste0( cn, " # ", vert_vars[nn], "=", vert_table[,nn] )
         }
     }
@@ -138,7 +137,7 @@ ANSI_create_table <- function (dat, criterion,
         if ( length(digits)!=V){
             digits <- rep(digits[1],V)
         }
-        for (vv in 1:V){
+        for (vv in 1L:V){
             # num1 <- round( as.numeric( paste(dfr[,vv])), digits )
             # g1 <- sprintf( paste0("%.",digits[vv], "f"), num1 )
             num1 <- as.numeric(paste(dfr[,vv]))
