@@ -1,15 +1,15 @@
 ## File Name: complete.miceadds.R
-## File Version: 0.124
+## File Version: 0.125
 
 #*** complete function for nested multiple imputation
 complete.mids.nmi <- function( data, action=c(1,1), ... )
 {
     x <- data
-    if ( x$type=="mice" ){
+    if ( x$type=='mice' ){
         x1 <- x$imp
         data <- mice::complete( data=x1[[ action[1] ]], action=action[2], ... )
     }
-    if ( x$type=="mice.1chain" ){
+    if ( x$type=='mice.1chain' ){
         data <- complete.mids.1chain( x$imp[[ action[1] ]], action=action[2], ...)
     }
     return(data)
