@@ -1,19 +1,19 @@
 ## File Name: datalist2mids.R
-## File Version: 0.432
+## File Version: 0.436
 
 datalist2mids <- function( dat.list, progress=FALSE )
 {
     CALL <- match.call()
     #--- preliminary check whether dat.list of type imputationList
-    if ( inherits(dat.list, "imputationList" ) ){
+    if ( inherits(dat.list, 'imputationList' ) ){
         dat.list <- dat.list$imputations
     }
-    #***
+
     M <- length(dat.list)
     if (M==1){
         dat0 <- dat.list[[1]]
-        dat0[,"__dummy"] <- 1
-        dat0[1,"__dummy"] <- NA
+        dat0[,'__dummy'] <- 1
+        dat0[1,'__dummy'] <- NA
         dat.list <- list( dat0, dat0 )
         M <- 2
     }
@@ -22,7 +22,7 @@ datalist2mids <- function( dat.list, progress=FALSE )
     datl2 <- matrix( NA, nrow=nrow(datl1), ncol=ncol(datl1) )
     colnames(datl2) <- colnames(datl1)
     VV <- ncol(datl1)
-    for ( vv in 1:VV){
+    for ( vv in 1L:VV){
         datl2[, vv] <- as.vector( datl1[,vv] )
     }
     datl1 <- as.data.frame(datl2)
@@ -35,21 +35,21 @@ datalist2mids <- function( dat.list, progress=FALSE )
     # more than one dataset=> typical imputation
     if (M > 1){
         if (progress){
-            cat("Analyze missing pattern\n-")
+            cat('Analyze missing pattern\n-')
             utils::flush.console()
         }
-        for (ii in 2:M){
+        for (ii in 2L:M){
             datl2 <- dat.list[[ii]]
             r1[, impvars] <- r1[,impvars] + 1*( datl2[,impvars] !=datl1[,impvars ] )
             datl1 <- datl2
             if (progress){
-                cat("-")
+                cat('-')
                 utils::flush.console()
             }
         }
     }
     if (progress){
-        cat("\n")
+        cat('\n')
         utils::flush.console()
     }
     r1[ r1>0 ] <- 1
@@ -60,7 +60,7 @@ datalist2mids <- function( dat.list, progress=FALSE )
     elimvars <- names(cM)[ cM > 0 ]
     pM <- imp0$predictorMatrix
     if ( length(elimvars) > 0 ){
-        iM[ elimvars ] <- ""
+        iM[ elimvars ] <- ''
         pM[  elimvars, ] <- 0
         pM[, elimvars ] <- 0
     }
@@ -70,10 +70,10 @@ datalist2mids <- function( dat.list, progress=FALSE )
     # fill in missing in mids object
     IMP <- imp1$imp
     if (progress){
-        cat("Create mids object\n")
+        cat('Create mids object\n')
         utils::flush.console()
     }
-    for (ii in 1:M){
+    for (ii in 1L:M){
         dat.ii <- dat.list[[ii]]
         for ( vv1 in seq( 1, length(impvars) ) ){
             vv <- names(impvars)[vv1]
@@ -83,25 +83,25 @@ datalist2mids <- function( dat.list, progress=FALSE )
             }
         }
         if (progress){
-            cat(".")
+            cat('.')
             utils::flush.console()
         }
     }
     if (progress){
-        cat("\n")
+        cat('\n')
     }
     imp1$imp <- IMP
-    iM[ imp1$nmis==0 ] <- ""
-    iM[ imp1$nmis > 0 ] <- "imputed"
+    iM[ imp1$nmis==0 ] <- ''
+    iM[ imp1$nmis > 0 ] <- 'imputed'
     imp1$method <- iM
     if ( is.numeric(imp1$visitSequence)){
         imp1$visitSequence <- -99 + 0*imp1$visitSequence
     } else {
-        imp1$visitSequence <- rep("", length(imp1$visitSequence) )
+        imp1$visitSequence <- rep('', length(imp1$visitSequence) )
     }
     # predictor matrix
     imp1$predictorMatrix <- -99 + 0*imp1$predictorMatrix
-    imp1$predictorMatrix[ iM=="", ] <- 0
+    imp1$predictorMatrix[ iM=='', ] <- 0
     imp1$call <- CALL
     return(imp1)
 }
