@@ -1,5 +1,5 @@
 ## File Name: fleishman_coef.R
-## File Version: 0.18
+## File Version: 0.192
 
 fleishman_coef <- function(mean=0, sd=1, skew=0, kurt=0)
 {
@@ -15,7 +15,7 @@ fleishman_coef <- function(mean=0, sd=1, skew=0, kurt=0)
         fct <- rep(0,3)
         fct[1] <- b^2+6*b*d+2*c^2+15*d^2-1
         fct[2] <- 2*c*(b^2+24*b*d+105*d^2+2) - skew
-        fct[3] <- 24*(b*d + c^2*(1+b^2+28*b*d) + d^2*(12+48*b*d+141*c^2 + 225*d^2 ) ) - kurt
+        fct[3] <- 24*(b*d + c^2*(1+b^2+28*b*d)+d^2*(12+48*b*d+141*c^2 + 225*d^2 ))-kurt
         res <- sum( fct^2 )
         return(res)
     }
@@ -25,7 +25,8 @@ fleishman_coef <- function(mean=0, sd=1, skew=0, kurt=0)
     if ( check_value < 0){
         out <- paste0("The condition 'kurt >=skew^2 - 2' has to be fulfilled.")
         kurt_min <- skew^2 - 2
-        out <- paste0( out, "\n  The kurtosis must be at least ", round( kurt_min, 3), ".\n")
+        out <- paste0( out, "\n  The kurtosis must be at least ",
+                                round( kurt_min, 3), ".\n")
         stop(out)
     }
 
