@@ -1,5 +1,5 @@
 ## File Name: ma_lme4_formula_terms.R
-## File Version: 0.155
+## File Version: 0.157
 
 ma_lme4_formula_terms <- function(formula)
 {
@@ -19,7 +19,8 @@ ma_lme4_formula_terms <- function(formula)
     for (rr in seq_len(NR)){
         s1 <- strsplit(t1r[[rr]], "\\|")[[1]]
         random_effects_id[[rr]] <- gsub( " ", "", s1[2])
-        formula_random[[rr]] <- stats::as.formula( paste0( "~ ", paste0( s1[1], collapse=" + " ) ) )
+        formula_random[[rr]] <- stats::as.formula( paste0( "~ ",
+                                        paste0( s1[1], collapse=" + " ) ) )
 
     }
     names(formula_random) <- random_effects_id
@@ -36,8 +37,9 @@ ma_lme4_formula_terms <- function(formula)
     formula_fixed1 <- stats::as.formula( paste0( " ~ ", rf1 ) )
 
     #--- output
-    res <- list( all_vars=all_vars, formula_fixed=formula_fixed, formula_random=formula_random,
-                random_effects_id=random_effects_id, formula_lhs=formula_lhs,
-                terms_fe=t1f, terms_re=t1r, NR=NR, formula_fixed1=formula_fixed1)
+    res <- list( all_vars=all_vars, formula_fixed=formula_fixed,
+                    formula_random=formula_random,
+                    random_effects_id=random_effects_id, formula_lhs=formula_lhs,
+                    terms_fe=t1f, terms_re=t1r, NR=NR, formula_fixed1=formula_fixed1)
     return(res)
 }
