@@ -1,10 +1,10 @@
 ## File Name: mice.impute.2l.groupmean.R
-## File Version: 0.17
+## File Version: 0.181
 
 mice.impute.2l.groupmean <- function (y, ry, x, type, grmeanwarning=TRUE, ...)
 {
     if ( ( ncol(x) > 2 ) & grmeanwarning ){
-        warning("\nMore than one variable is requested to be aggregated.\n")
+        warning('\nMore than one variable is requested to be aggregated.\n')
     }
     clusterx <- paste( x[,type==-2] )
     a1 <- rowsum( x[, type %in% c(1,2) ], clusterx,  na.rm=TRUE )
