@@ -1,5 +1,5 @@
 ## File Name: mice_imputation_bygroup_modify_arguments.R
-## File Version: 0.08
+## File Version: 0.09
 
 
 mice_imputation_bygroup_modify_arguments <- function(args, ind_gg,
@@ -7,7 +7,7 @@ mice_imputation_bygroup_modify_arguments <- function(args, ind_gg,
 {
     Nmis <- sum(!args$ry)
     args_imputation_function <- methods::formalArgs(def=imputation_function)
-    if ( "wy" %in% args_imputation_function ){
+    if ( 'wy' %in% args_imputation_function ){
         args$wy <- wy[ind_gg]
         Nmis <- sum(args$wy)
     }
