@@ -1,5 +1,5 @@
 ## File Name: mice_ml_lmer_arrange_cluster_identifiers.R
-## File Version: 0.06
+## File Version: 0.12
 
 
 mice_ml_lmer_arrange_cluster_identifiers <- function( levels_id, data )
@@ -15,6 +15,9 @@ mice_ml_lmer_arrange_cluster_identifiers <- function( levels_id, data )
         clus_unique__[[ll]] <- clus_unique
         ngr[[ll]] <- length(clus_unique)
     }
+    names(clus_unique__) <- levels_id
+    names(ngr) <- levels_id
+    names(clus__) <- levels_id
     #---- output
     res <- list( NL=NL, clus=clus__, ngr=ngr, clus_unique=clus_unique__ )
     return(res)
