@@ -1,9 +1,9 @@
 ## File Name: miceadds_ginv.R
-## File Version: 0.01
+## File Version: 0.02
 
 miceadds_ginv <- function(x, ...)
 {
-    requireNamespace("MASS")
+    requireNamespace('MASS')
     y <- MASS::ginv(X=x, ...)
     return(y)
 }
