@@ -1,9 +1,8 @@
 ## File Name: zzz.R
-## File Version: 0.15
+## File Version: 0.161
+
 #  zzz.R
 #
-# This function is simply copied from mice package.
-
 version <- function(pkg="miceadds")
 {
     lib <- dirname(system.file(package=pkg))
@@ -11,11 +10,9 @@ version <- function(pkg="miceadds")
     return(paste(d$Package,d$Version,d$Date,lib))
 }
 
-# on attach TAM
 .onAttach <- function(libname,pkgname)
 {
-    d <- utils::packageDescription("miceadds")
-    packageStartupMessage(
-            paste0( "* ", d$Package," ", d$Version," (",d$Date,")")
-    )
+    d <- utils::packageDescription('miceadds')
+    v1 <- paste0( '* ', d$Package,' ', d$Version,' (',d$Date,')')
+    packageStartupMessage(v1)
 }
